==> qt-creator-opensource-src-4.0.1.tar.gz: qt-creator-opensource-src-4.0.1/src/plugins/qmldesigner/components/navigator/iconcheckboxitemdelegate.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#ifndef QMLDESIGNER_ICONCHECKBOXITEMDELEGATE_H
#define QMLDESIGNER_ICONCHECKBOXITEMDELEGATE_H

#include <QStyledItemDelegate>

namespace QmlDesigner {

class NavigatorTreeModel;

class IconCheckboxItemDelegate : public QStyledItemDelegate
{
public:
    explicit IconCheckboxItemDelegate(QObject *parent,
                                      const QPixmap &checkedPixmap,
                                      const QPixmap &uncheckedPixmap,
                                      NavigatorTreeModel *treeModel);

    QSize sizeHint(const QStyleOptionViewItem &option,
                   const QModelIndex &index) const;

    void paint(QPainter *painter,
               const QStyleOptionViewItem &option,
               const QModelIndex &index) const;

private:
    const QPixmap m_checkedPixmap;
    const QPixmap m_uncheckedPixmap;
    NavigatorTreeModel *m_navigatorTreeModel;
};
} // namespace QmlDesigner

#endif // QMLDESIGNER_ICONCHECKBOXITEMDELEGATE_H

==> qt-creator-opensource-src-4.2.0.tar.gz: qt-creator-opensource-src-4.2.0/src/plugins/qmldesigner/components/navigator/iconcheckboxitemdelegate.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include <QStyledItemDelegate>

namespace QmlDesigner {

class NavigatorTreeModel;

class IconCheckboxItemDelegate : public QStyledItemDelegate
{
public:
    explicit IconCheckboxItemDelegate(QObject *parent,
                                      const QPixmap &checkedPixmap,
                                      const QPixmap &uncheckedPixmap,
                                      NavigatorTreeModel *treeModel);

    QSize sizeHint(const QStyleOptionViewItem &option,
                   const QModelIndex &index) const;

    void paint(QPainter *painter,
               const QStyleOptionViewItem &option,
               const QModelIndex &index) const;

private:
    const QPixmap m_checkedPixmap;
    const QPixmap m_uncheckedPixmap;
    NavigatorTreeModel *m_navigatorTreeModel;
};
} // namespace QmlDesigner
